@@ -13,18 +13,18 @@ compile_iss <- function() {
   app_dir   <- getOption("RInno.app_dir")
 
   # Find the command line compiler for Inno Setup
-  progs <- c(list.dirs("C:/Program Files", T, F),
-             list.dirs("C:/Program Files (x86)", T, F))
+  progs <- c(list.dirs("C:/Program Files", TRUE, FALSE),
+             list.dirs("C:/Program Files (x86)", TRUE, FALSE))
 
   inno <- progs[grep("Inno Setup", progs)]
 
-  if (!dir.exists(inno)) stop("Make sure Inno Setup is installed to 'C:/Program Files'. Call install_inno(), and try again!")
+  if (!dir.exists(inno)) stop("Make sure Inno Setup is installed to 'C:/Program Files'. Call install_inno(), and try again!", call. = FALSE)
 
   compil32 <- file.path(inno, "Compil32.exe")
 
-  if (!file.exists(compil32)) stop(sprintf("Failed to find %s. Install Inno Setup via install_inno(), and try again!", compil32))
+  if (!file.exists(compil32)) stop(glue::glue("Failed to find {compil32}. Install Inno Setup via install_inno(), and try again!"), call. = FALSE)
 
   iss_file <- file.path(app_dir, paste0(app_name, ".iss"))
 
-  system(sprintf('"%s" /cc "%s"', compil32, iss_file))
+  system(glue::glue('"{compil32}" /cc "{iss_file}"'))
 }
