@@ -12,6 +12,6 @@
 #' @export
 
 create_bat <- function(app_name, app_dir) {
-  writeLines("wscript wsf\\run.wsf",
+  writeLines("wscript utils\\wsf\\run.wsf",
              file.path(app_dir, paste0(app_name, ".bat")))
 }
