@@ -1,8 +1,10 @@
-#' Creates an app config file, "config.cfg"
+#' Creates an app config file, "utils/config.cfg"
 #'
 #' @inheritParams create_app
 #' @param remotes Character vector of GitHub repository addresses in the format \code{username/repo[/subdir][\@ref|#pull]} for GitHub package dependencies.
+#' @param locals Character vector of local package binary dependencies.
 #' @param repo Default repository to install package dependencies from. This defaults to \code{repo = "http://cran.rstudio.com"}.
+#' @param local_path Default location inside the app working directory to install local package dependencies from. This defaults to \code{local_path = "local"}
 #' @param error_log Name of error logging file. Contains start up errors from \emph{run.R}.
 #' @param app_repo_url Repository address in the format \code{"https://bitbucket.org/username/repo"} (\code{repo = app_name}). Only Bitbucket and GitHub repositories are supported.
 #' @param auth_user Bitbucket username. It is recommended to create a read-only account for each app.  Support for OAuth 2 and tokens is in the works.
@@ -16,20 +18,29 @@
 #' @seealso \code{\link{create_app}}.
 #' @export
 
-create_config <- function(app_name, app_dir, pkgs,
-  remotes = "none", repo = "http://cran.rstudio.com",  error_log = "error.log",
-  app_repo_url = "none", auth_user = "none", auth_pw = "none", auth_token = "none",
-  user_browser = "chrome") {
+create_config <- function(app_name, app_dir, pkgs, locals = "none",
+  remotes = "none", repo = "http://cran.rstudio.com", local_path = 'local',
+  error_log = "error.log", app_repo_url = "none", auth_user = "none",
+  auth_pw = "none", auth_token = "none", user_browser = "chrome") {
 
   # Reset defaults if empty
   for (formal in names(formals(create_config))) {
     if (length(get(formal)) == 0) assign(formal, formals(create_config)[formal])
   }
 
+  # Check pkgs/locals class
+  if (any(lapply(pkgs, class) != "character")) stop("`pkgs` must be a character vector.", call. = FALSE)
+
+  if (any(lapply(locals, class) != "character")) stop("`locals` must be a character vector.", call. = FALSE)
+
+  # If app_dir/utils does not exist, create it
+  if (!dir.exists(app_dir)) dir.create(app_dir)
+  if (!dir.exists(file.path(app_dir, "utils"))) dir.create(file.path(app_dir, "utils"))
+
   if (app_repo_url != "none") {
     # Fail early
-    if (!any(grepl('bitbucket', app_repo_url), grepl('github', app_repo_url))) {
-      stop(sprintf("%s is not a valid app_repo_url.", app_repo_url))
+    if (!any(grepl("bitbucket", app_repo_url), grepl("github", app_repo_url))) {
+      stop(sprintf("%s is not a valid app_repo_url.", app_repo_url), call. = FALSE)
     }
 
     # Set app_repo
@@ -68,14 +79,15 @@ create_config <- function(app_name, app_dir, pkgs,
   jsonlite::write_json(
     list(
       appname = app_name,
-      pkgs = list(pkgs = pkgs, cran = repo),
+      pkgs = list(pkgs = standardize_pkgs(pkgs), cran = repo),
+      remotes = remotes,
+      locals = list(pkgs = standardize_pkgs(locals), local = local_path),
       logging = error_log,
       host = host,
       app_repo = app_repo,
       auth_user = auth_user,
       auth_pw = auth_pw,
       auth_token = auth_token,
-      remotes = remotes,
       user_browser = tolower(user_browser),
       flex_file = flex_file),
     file.path(app_dir, "utils/config.cfg"), pretty = T, auto_unbox = T)
