@@ -12,7 +12,6 @@
 #' @author Tal Galili and Jonathan M. Hill
 #'
 #' @param quick_start_pack The Inno Setup QuickStart Pack includes Inno Setup and Inno Script Studio script editor. See \href{http://www.jrsoftware.org/is3rdparty.php}{Third-Party Files} page for more information.
-#' @param encryption_module TRUE/FALSE. By default Inno Setup does not include its encryption module, but it is required to add a password to an installer via \code{inst_pw}. Defaults to TRUE.
 #'
 #' @param ... extra parameters to pass to \code{\link[installr]{install.URL}}
 #'
@@ -26,7 +25,7 @@
 #' @export
 
 install_inno <- function(
-  quick_start_pack = FALSE, encryption_module = TRUE,
+  quick_start_pack = FALSE,
   ...) {
 
   page_with_download_url = 'http://www.jrsoftware.org/download.php/'
@@ -39,17 +38,4 @@ install_inno <- function(
   URL <- paste0(page_with_download_url, exe_filename)
 
   installr::install.URL(URL, ...)
-
-  if (encryption_module) {
-    # Find the Inno Setup folder
-    progs <- c(list.dirs("C:/Program Files", T, F),
-               list.dirs("C:/Program Files (x86)", T, F))
-
-    inno <- progs[grep("Inno Setup", progs)]
-
-    # Create a temp file and add the encryption module
-    temp <- tempfile()
-    utils::download.file("http://www.jrsoftware.org/download.php/iscrypt.dll", temp)
-    file.copy(temp, file.path(inno, "ISCrypt.dll"))
-  }
 }
